class Align:
    """
    Alignment of an image on the display.
    """
    BOTTOM_LEFT: ...
    BOTTOM: ...
    BOTTOM_RIGHT: ...
    LEFT: ...
    CENTER: ...
    RIGHT: ...
    TOP_LEFT: ...
    TOP: ...
    TOP_RIGHT: ...


class Button:
    """
    Buttons on a brick or remote.
    """
    LEFT_DOWN: ...
    DOWN: ...
    RIGHT_DOWN: ...
    LEFT: ...
    CENTER: ...
    RIGHT: ...
    LEFT_UP: ...
    UP: ...
    BEACON: ...
    RIGHT_UP: ...


class Color:
    """
    Light or surface color.
    """
    BLACK: ...
    BLUE: ...
    GREEN: ...
    YELLOW: ...
    RED: ...
    WHITE: ...
    BROWN: ...
    ORANGE: ...
    PURPLE: ...


class Port:
    """
    Port on the EV3 Programmable Brick.

    ----------
    Motor Ports: A, B, C, D

    Sensor Ports: S1, S2, S3, S4
    """
    A: ...
    B: ...
    C: ...
    D: ...
    S1: ...
    S2: ...
    S3: ...
    S4: ...


class Direction:
    """
    Rotational direction for positive speed values: clockwise or counterclockwise.
    For all motors, this is defined when looking at the shaft, just like looking at a clock.
    For NXT or EV3 motors, make sure to look at the motor with the red/orange shaft to the lower right.

    ----------
    CLOCKWISE: A positive speed value should make the motor move clockwise.

    COUNTERCLOCKWISE: A positive speed value should make the motor move counterclockwise.
    """
    CLOCKWISE: ...
    COUNTERCLOCKWISE: ...


class Stop:
    """
    Action after the motor stops: coast, brake, or hold.

    ----------
    COAST: Let the motor move freely.

    BRAKE: Passively resist small external forces.

    HOLD: Keep controlling the motor to hold it at the commanded angle. This is only available on motors with encoders.
    """
    COAST: ...
    BRAKE: ...
    HOLD: ...


class ImageFile:
    """
    Paths to standard EV3 images.

    ----------
    Information: RIGHT, FORWARD, ACCEPT, QUESTION_MARK, STOP_1, LEFT, DECLINE, THUMBS_DOWN, BACKWARD, NO_GO, WARNING, STOP_2, THUMBS_UP

    LEGO&reg;: EV3, EV3_ICON

    Objects: TARGET

    Eyes: BOTTOM_RIGHT, BOTTOM_LEFT, EVIL, CRAZY_2, KNOCKED_OUT, PINCHED_RIGHT, WINKING, DIZZY, DOWN, TIRED_MIDDLE, MIDDLE_RIGHT, SLEEPING, MIDDLE_LEFT, TIRED_RIGHT, PINCHED_LEFT, PINCHED_MIDDLE, CRAZY_1, NEUTRAL, AWAKE, UP, TIRED_LEFT, ANGRY
    """
    RIGHT: ...
    FORWARD: ...
    ACCEPT: ...
    QUESTION_MARK: ...
    STOP_1: ...
    LEFT: ...
    DECLINE: ...
    THUMBS_DOWN: ...
    BACKWARD: ...
    NO_GO: ...
    WARNING: ...
    STOP_2: ...
    THUMBS_UP: ...
    EV3: ...
    EV3_ICON: ...
    TARGET: ...
    BOTTOM_RIGHT: ...
    BOTTOM_LEFT: ...
    EVIL: ...
    CRAZY_2: ...
    KNOCKED_OUT: ...
    PINCHED_RIGHT: ...
    WINKING: ...
    DIZZY: ...
    DOWN: ...
    TIRED_MIDDLE: ...
    MIDDLE_RIGHT: ...
    SLEEPING: ...
    MIDDLE_LEFT: ...
    TIRED_RIGHT: ...
    PINCHED_LEFT: ...
    PINCHED_MIDDLE: ...
    CRAZY_1: ...
    NEUTRAL: ...
    AWAKE: ...
    UP: ...
    TIRED_LEFT: ...
    ANGRY: ...


class SoundFile:
    """
    Paths to standard EV3 sounds.

    ----------
    Expressions: SHOUTING, CHEERING, CRYING, OUCH, LAUGHING_2, SNEEZING, SMACK, BOING, BOO, UH_OH, SNORING, KUNG_FU, FANFARE, CRUNCHING, MAGIC_WAND, LAUGHING_1

    Information: LEFT, BACKWARDS, RIGHT, OBJECT, COLOR, FLASHING, ERROR, ERROR_ALARM, DOWN, FORWARD, ACTIVATE, SEARCHING, TOUCH, UP, ANALYZE, STOP, DETECTED, TURN, START

    Communication: MORNING, EV3, GO, GOOD_JOB, OKEY_DOKEY, GOOD, NO, THANK_YOU, YES, GAME_OVER, OKAY, SORRY, BRAVO, GOODBYE, HI, HELLO, MINDSTORMS, LEGO, FANTASTIC

    Movements: SPEED_IDLE, SPEED_DOWN, SPEED_UP

    Color: BROWN, GREEN, BLACK, WHITE, RED, BLUE, YELLOW

    Mechanical: TICK_TACK, HORN_1, BACKING_ALERT, MOTOR_IDLE, AIR_RELEASE, AIR, BRAKE, RATCHET, MOTOR_STOP, HORN_2, LASER, SONAR, MOTOR_START

    Animals: INSECT_BUZZ_2, ELEPHANT_CALL, SNAKE_HISS, DOG_BARK_2, DOG_WHINE, INSECT_BUZZ_1, DOG_SNIFF, T_REX_ROAR, INSECT_CHIRP, DOG_GROWL, SNAKE_RATTLE, DOG_BARK_1, CAT_PURR

    Numbers: ZERO, ONE, TWO, THREE, FOUR, FIVE, SIX, SEVEN, EIGHT, NINE, TEN

    System: READY, CONFIRM, GENERAL_ALERT, CLICK, OVERPOWER
    """
    SHOUTING: ...
    CHEERING: ...
    CRYING: ...
    OUCH: ...
    LAUGHING_2: ...
    SNEEZING: ...
    SMACK: ...
    BOING: ...
    BOO: ...
    UH_OH: ...
    SNORING: ...
    KUNG_FU: ...
    FANFARE: ...
    CRUNCHING: ...
    MAGIC_WAND: ...
    LAUGHING_1: ...
    LEFT: ...
    BACKWARDS: ...
    RIGHT: ...
    OBJECT: ...
    COLOR: ...
    FLASHING: ...
    ERROR: ...
    ERROR_ALARM: ...
    DOWN: ...
    FORWARD: ...
    ACTIVATE: ...
    SEARCHING: ...
    TOUCH: ...
    UP: ...
    ANALYZE: ...
    STOP: ...
    DETECTED: ...
    TURN: ...
    START: ...
    MORNING: ...
    EV3: ...
    GO: ...
    GOOD_JOB: ...
    OKEY_DOKEY: ...
    GOOD: ...
    NO: ...
    THANK_YOU: ...
    YES: ...
    GAME_OVER: ...
    OKAY: ...
    SORRY: ...
    BRAVO: ...
    GOODBYE: ...
    HI: ...
    HELLO: ...
    MINDSTORMS: ...
    LEGO: ...
    FANTASTIC: ...
    SPEED_IDLE: ...
    SPEED_DOWN: ...
    SPEED_UP: ...
    BROWN: ...
    GREEN: ...
    BLACK: ...
    WHITE: ...
    RED: ...
    BLUE: ...
    YELLOW: ...
    TICK_TACK: ...
    HORN_1: ...
    BACKING_ALERT: ...
    MOTOR_IDLE: ...
    AIR_RELEASE: ...
    AIR: ...
    BRAKE: ...
    RATCHET: ...
    MOTOR_STOP: ...
    HORN_2: ...
    LASER: ...
    SONAR: ...
    MOTOR_START: ...
    INSECT_BUZZ_2: ...
    ELEPHANT_CALL: ...
    SNAKE_HISS: ...
    DOG_BARK_2: ...
    DOG_WHINE: ...
    INSECT_BUZZ_1: ...
    DOG_SNIFF: ...
    T_REX_ROAR: ...
    INSECT_CHIRP: ...
    DOG_GROWL: ...
    SNAKE_RATTLE: ...
    DOG_BARK_1: ...
    CAT_PURR: ...
    ZERO: ...
    ONE: ...
    TWO: ...
    THREE: ...
    FOUR: ...
    FIVE: ...
    SIX: ...
    SEVEN: ...
    EIGHT: ...
    NINE: ...
    TEN: ...
    READY: ...
    CONFIRM: ...
    GENERAL_ALERT: ...
    CLICK: ...
    OVERPOWER: ...



from pybricks.parameters import Align, Button, Color
from typing import List, Tuple


class sound:
    @classmethod
    def beep(cls, frequency: int = 500, duration: int = 100, volume: int = 30):
        """
        Play a beep/tone.

        ----------
        frequency : int - Frequency of the beep in Hertz (Default: 500).

        duration : int - Duration of the beep in milliseconds (Default: 100).

        volume : int - Volume of the beep as a percentage (Default: 30).
        """
        ...

    @classmethod
    def beeps(cls, number: int):
        """
        Play a number of default beeps with a brief pause in between.

        ----------
        number : int – Number of beeps.
        """
        ...

    @classmethod
    def file(cls, file_name: str, volume: int = 100):
        """
        Play a sound file.

        ----------
        file_name : str – Path to the sound file, including extension.

        volume : int - Volume of the sound as a percent. (Default: 100).
        """
        ...


class display:
    @classmethod
    def clear(cls):
        """
        Clear everything on the display.
        """

    @classmethod
    def image(cls, file_name: str, alignment: Align = Align.CENTER, coordinate: Tuple[int, int] = None, clear: bool = True):
        """
        Show an image file. You can specify its placement either using alignmentor by specifying a coordinate, 
        but not both.

        ----------
        file_name : str – Path to the image file. Paths may be absolute or relative from theproject folder.

        alignment : Align – Where to place the image (Default: Align.CENTER).

        coordinate : Tuple[int, int] – (x, y) coordinate tuple. It is the top-left corner of the image (Default: None).

        clear : bool – Whether to clear the screen before showing the image (Default:True).
        """
        ...

    @classmethod
    def text(cls, text: str, coordinate: Tuple[int, int] = None):
        """
        Display text.

        ----------
        text : str – The text to display.

        coordinate : Tuple[int, int] – (x, y) coordinate tuple (Default: None). It is the top-left corner of the first character. If no coordinate is specified, it is printed on the next line.
        """
        ...


class battery:
    @classmethod
    def current(cls) -> int:
        """
        Get the current supplied by the battery.

        ----------
        Returns - Battery current (mA).
        """
        ...

    @classmethod
    def voltage(cls) -> int:
        """
        Get the voltage of the battery.

        ----------
        Returns - Battery voltage (mV).
        """
        ...


def buttons() -> List[Button]:
    """
    Check which buttons on the EV3 Brick are currently pressed.

    ----------
    Returns - List of pressed buttons.
    """
    ...


def light(color: Color):
    """
    Set the color of the brick light.

    ----------
    color : Color – Color of the light.  Choose Color.BLACK or None to turn the light off.
    """
    ...



def print(*value, sep: str = ' ', end: str = '\n', file=sys.stdout, flush: bool = False):
    """
    Print values on the terminal or a stream

    ----------
    value - Things to print (see Python print() docs).

    sep : str - The string that separates the arguments in value (Default: space).

    end : str - The string that ends the print (Default: new line).

    file - an object with a write(string) method (Default: sys.stdout).

    flush : bool - True to forcibly flush the stream.
    """
    ...


def wait(time: int):
    """
    Pause the user program for a specified amount of time.

    ----------
    time : int - How long to wait in milliseconds
    """
    ...


class StopWatch:
    """
    A stopwatch to measure time intervals. Similar to the stopwatch feature on your phone.
    """

    def time(self) -> int:
        """
        Get the current time of the stopwatch.

        ----------
        Returns - Elapsed time in milliseconds.
        """
        ...

    def pause(self):
        """
        Pause the stopwatch.
        """
        ...

    def resume(self):
        """
        Resume the stopwatch.
        """
        ...

    def reset(self):
        """
        Reset the stopwatch time to 0. The run state is unaffected:
        - If it was paused, it stays paused (but now at 0).
        - If it was running, it stays running (but starting again from 0)
        """
        ...



from pybricks.parameters import Button, Color, Direction, Port, Stop
from typing import List, Tuple


class Motor:
    """
    LEGO® MINDSTORMS® EV3 Medium or Large Motor. Element 99455/6148292 or 95658/6148278, contained in:
    - 31313: LEGO® MINDSTORMS® EV3 (2013)
    - 45544: LEGO® MINDSTORMS® Education EV3 Core Set (2013)
    - 45503 or 45502: Separate part (2013)
    """

    def __init__(self, port: Port, direction: Direction = Direction.CLOCKWISE, gears: List[int, int] = None):
        """
        LEGO® MINDSTORMS® EV3 Medium or Large Motor.
        ----------

        port : Port – Port to which the motor is connected.

        direction : Direction – Positive speed direction (Default: Direction.CLOCKWISE).

        gears : List[int, int] – List of gears linked to the motor (Default:None). For example: [12, 36] represents a gear train with a 12-tooth and a 36-tooth gear. Use a list of lists for multiple gear trains, such as [[12, 36], [20, 16, 40]]. The gears setting is only available for motors with rotation sensors.
        """
        ...

    def dc(self, duty: float):
        """
        Set the duty cycle of the motor.

        ----------
        duty : float - The duty cycle as a percentage (-100.0 to 100).
        """
        ...

    def angle(self) -> int:
        """
        Get the rotation angle of the motor.

        ----------
        Returns - Motor angle in degrees.
        """
        ...

    def reset_angle(self, angle: int):
        """
        Reset the accumulated rotation angle of the motor.

        ----------
        angle : float – Value to which the angle should be reset in degrees.
        """
        ...

    def speed(self) -> int:
        """
        Get the speed (angular velocity) of the motor.

        ----------
        Returns - Motor speed in degrees/second.
        """
        ...

    def stop(self, stop_type: Stop = Stop.COAST):
        """
        Stop the motor.

        ----------
        stop_type : Stop – Whether to coast, brake, or hold (Default: Stop.COAST).
        """
        ...

    def run(self, speed: int):
        """
        Keep the motor running at a constant speed (angular velocity). The motor will accelerate towards the requested speed and the duty cycle is automatically adjusted to keep the speed constant, even under some load. This continues in the background until you give the motor a new command or the program stops.

        ----------
        speed : float – Speed of the motor in degrees/second.
        """
        ...

    def run_time(self, speed: int, time: int, stop_type: Stop = Stop.COAST, wait: bool = True):
        """
        Run the motor at a constant speed (angular velocity) for a given amount of time. The motor will accelerate towards the requested speed and the duty cycle is automatically adjusted to keep the speed constant, even under some load. It begins to decelerate just in time to reach stand still after the specified duration.

        ----------
        speed : float - Speed of the motor (degrees/second).

        time : int – Duration of the maneuver (milliseconds).

        stop_type : Stop – Whether to coast, brake, or hold after coming to a stand still (Default: Stop.COAST).

        wait : bool – Wait for the maneuver to complete before continuing with the rest of the program (Default: True). This means that your program waits for the specified time.
        """
        ...

    def run_angle(self, speed: int, rotation_angle: int, stop_type: Stop = Stop.COAST, wait: bool = True):
        """
        Run the motor at a constant speed (angular velocity) by a given angle. The motor will accelerate towards the requested speed and the duty cycle is automatically adjusted to keep the speed constant, even under some load. It begins to decelerate just in time so that it comes to a stand still after traversing the given angle.

        ----------
        speed : float – Speed of the motor (degrees/second).

        rotation_angle : float – Angle by which the motor should rotate (degree).

        stop_type : Stop – Whether to coast, brake, or hold after coming to a stand still (Default: Stop.COAST).

        wait : bool – Wait for the maneuver to complete before continuing with the rest of the program (Default: True). This means that your program waits until the motor has traveled precisely the requested angle.
        """
        ...

    def run_target(self, speed: int, target_angle: int, stop_type: Stop = Stop.COAST, wait: bool = True):
        """
        Run the motor at a constant speed (angular velocity) towards a given target angle. The motor will accelerate towards the requested speed and the duty cycle is automatically adjusted to keep the speed constant, even under some load. It begins to decelerate just in time so that it comes to a stand still at the given target angle. The direction of rotation is automatically selected based on the target angle.

        ----------
        speed : float - Absolute speed of the motor (degrees/second). The direction will be automatically selected based on the target angle: it makes no difference if you specify a positive or negative speed.

        target_angle : float – Target angle that the motor should rotate to, regardless of its current angle (degrees).

        stop_type : Stop – Whether to coast, brake, or hold after coming to a stand still (Default: Stop.COAST).

        wait : bool – Wait for the maneuver to complete before continuing with the rest ofthe program (Default: True). This means that your program waits until the motor has reached the target angle.
        """
        ...

    def track_target(self, target_angle: int):
        """
        Track a target angle that varies in time. This function is quite similar to run_target(), but speed and acceleration settings are ignored: it will move to the target angle as fast as possible. Instead, you adjust speed and acceleration by choosing how fast or slow you vary the target_angle. This method is useful in fast loops where the motor target changes continuously.

        ----------
        target_angle : float – Target angle that the motor should rotate to (degrees).
        """
        ...

    def stalled(self) -> bool:
        """
        Check whether the motor is currently stalled. A motor is stalled when it cannot move even with the maximum torque. For example, when something is blocking the motor or your mechanism simply cannot turn any further. Specifically, the motor is stalled when the duty cycle computed by the PID controllers has reached the maximum (so duty=duty_limit) and still the motor cannot reach a minimal speed (so speed < stall_speed) for a period of at least stall_time. You can change the duty_limit, stall_speed,and stall_time settings using set_dc_settings() and set_pid_settings() in order to change the sensitivity to being stalled.

        ----------
        Returns - True if the motor is stalled, False if it is not.
        """
        ...

    def run_until_stalled(self, speed: int, stop_type: Stop = Stop.COAST, duty_limit: float = 100):
        """
        Run the motor at a constant speed (angular velocity) until it stalls. The motor is considered stalled when it cannot move even with the maximum torque. See stalled() for a more precise definition. The duty_limit argument lets you temporarily limit the motor torque during this maneuver. This is useful to avoid applying the full motor torque to a geared or lever mechanism.

        ----------
        speed : float - Speed of the motor (degrees/second).

        stop_type : Stop – Whether to coast, brake, or hold after coming to a stand still (Default: Stop.COAST).

        duty_limit : float - Relative  torque  limit as a percentage [0.0 to 100.0]. This limit works just like set_dc_settings(), but in this case the limit is temporary: it returns to its previous value after completing this command (Default: 100).
        """
        ...

    def set_dc_settings(self, duty_limit: float = 100, duty_offset: float = 0.0):
        """
        Configure the settings to adjust the behavior of the dc() command. This also affects all of the run commands, which use the dc() method in the background.

        ----------
        duty_limit : float - Relative torque limit during subsequent motor commands as a percentage [0.0 to 100.0]. This sets the maximum duty cycle that is applied during any subsequent motor command. This reduces the maximum torque output to a percentage of the absolute maximum stall torque. This is useful to avoid applying the full motor torque to a geared or lever mechanism, or to prevent your LEGO® train from unintentionally going at full speed. (Default: 100).

        duty_offset : float – Minimum duty cycle given when you use dc() as a percentage [0.0 to 100.0]. This adds a small feed forward torque so that your motor will move even for very low duty cycle values, which can be useful when you create your own feedback controllers (Default: 0).
        """
        ...

    def set_run_settings(self, max_speed: int, acceleration: int):
        """
        Configure the maximum speed and acceleration/deceleration of the motor for all run commands. This applies to the run, run_time, run_angle, run_target, or run_until_stalled commands you give the motor. See also the default parameters for each motor.

        ----------
        max_speed : float – Maximum speed of the motor during a motor command (degrees/second).

        acceleration : float –  Acceleration  towards  the  targetspeed and deceleration towards stand still (degrees/second/second). This should be a positive value. The motor will automatically change the sign to decelerate as needed.
        """
        ...

    def set_pid_settings(self, kp: int, ki: int, kd: int, tight_loop_limit: float, angle_tolerance: int, speed_tolerance: int, stall_speed: int, stall_time: int):
        """
        Configure the settings of the position and speed controllers. See also pid and the default parameters for each motor.

        ----------
        kp : int – Proportional position (and integral speed) control constant.

        ki : int – Integral position control constant.

        kd : int – Derivative position (and proportional speed) control constant. 

        tight_loop_limit : float – If you execute any of the run commands within this interval after starting the previous command, the controllers assume that you want to control the speed directly (ms). This means that it will ignore the acceleration setting and immediately begin tracking the speed you give in the run command. This is useful in a fast loop, where you usually want the motors to respond quickly rather than accelerate smoothly, for example with a line-following robot.

        angle_tolerance : float – Allowed deviation from the target angle before motion is considered complete (degrees).

        speed_tolerance : float – Allowed deviation from zero speed before motion is considered complete (deg/s).

        stall_speed : float – See stalled() (deg/s).

        stall_time : float - See stalled() (ms).
        """
        ...


class TouchSensor:
    """
    LEGO® MINDSTORMS® EV3 Touch Sensor. Element 95648/6138404, contained in:
    - 31313: LEGO® MINDSTORMS® EV3 (2013)
    - 45544: LEGO® MINDSTORMS® Education EV3 Core Set (2013)
    - 45507: Separate part (2013)
    """

    def __init__(self, port: Port):
        """
        LEGO® MINDSTORMS® EV3 Touch Sensor.

        ----------
        port : Port – Port to which the sensor is connected.
        """
        ...

    def pressed(self) -> bool:
        """
        Check if the sensor is pressed.

        ----------
        Returns - True if the sensor is pressed, False if it is not pressed.
        """
        ...


class ColorSensor:
    """
    LEGO® MINDSTORMS® EV3 Color Sensor. Element 95650/6128869, contained in:
    - 31313: LEGO® MINDSTORMS® EV3 (2013)
    - 45544: LEGO® MINDSTORMS® Education EV3 Core Set (2013)
    - 45506: Separate part (2013)
    """

    def __init__(self, port: Port):
        """
        LEGO® MINDSTORMS® EV3 Color Sensor.

        ----------
        port : Port – Port to which the sensor is connected.
        """
        ...

    def color(self) -> Color:
        """
        Measure the color of a surface.

        ----------
        Returns - Color.BLACK, Color.BLUE, Color.GREEN, Color.YELLOW, Color.RED, Color.WHITE Color.BROWN or None.
        """
        ...

    def ambient(self) -> int:
        """
        Measure the ambient light intensity.

        ----------
        Returns - Ambient light intensity, ranging from 0 (dark) to 100 (bright).
        """
        ...

    def reflection(self) -> int:
        """
        Measure the reflection of a surface using a red light.

        ----------
        Returns - Reflection, ranging from 0 (no reflection) to 100 (high reflection).
        """
        ...

    def rgb(self) -> Tuple[float, float, float]:
        """
        Measure the reflection of a surface using a red, green, and then a blue light.

        ----------
        Returns - Reflection for red, green, and blue light, each ranging from 0.0 (no reflection) to 100.0(high reflection).
        """
        ...


class InfraredSensor:
    """
    LEGO® MINDSTORMS® EV3 Infrared Sensor and Beacon. Element 95654/6132629 and 72156/6127283, contained in:
    - 31313: LEGO® MINDSTORMS® EV3 (2013)
    - 45509 and 45508: Separate parts (2013)
    """

    def __init__(self, port: Port):
        """
        LEGO® MINDSTORMS® EV3 Infrared Sensor and Beacon. 

        ----------
        port : Port – Port to which the sensor is connected.
        """
        ...

    def distance(self) -> float:
        """
        Measure the relative distance between the sensor and an object using infrared light.

        ----------
        Returns - Relative distance ranging from 0 (closest) to 100 (farthest).
        """
        ...

    def beacon(self, channel: int) -> Tuple[float, float]:
        """
        Measure the relative distance and angle between the remote and the infrared sensor.

        ----------
        channel : int – Channel number of the remote.

        ----------
        Returns - Tuple of relative distance (0 to 100) and approximate angle (-75 to 75 degrees) between remote and infrared sensor or (None,None) if no remote is detected.
        """
        ...

    def buttons(self, channel: int) -> List[Button]:
        """
        Check which buttons on the infrared remote are pressed.

        ----------
        channel : int – Channel number of the remote.

        ----------
        Returns - List of pressed buttons on the remote on the specified channel.
        """
        ...


class UltrasonicSensor:
    """
    LEGO® MINDSTORMS® EV3 Ultrasonic Sensor. Element 95652/6138403, contained in:
    - 45544: LEGO® MINDSTORMS® Education EV3 Core Set (2013)
    - 45504: Separate part (2013)
    """

    def __init__(self, port: Port):
        """
        LEGO® MINDSTORMS® EV3 Ultrasonic Sensor.

        ----------
        port : Port – Port to which the sensor is connected.
        """
        ...

    def distance(self, silent: bool = False) -> int:
        """
        Measure the distance between the sensor and an object using ultrasonic sound waves.

        ----------
        silent : bool – Choose True to turn the sensor off after measuring the distance. Choose False to leave the sensor on (Default). When you choose silent=True, the sensor does not emit sounds waves except when taking the measurement. This reduces interference with other ultrasonic sensors, but turning the sensor off takes approximately 300 ms each time.

        ----------
        Returns - Distance (millimeters).
        """
        ...

    def presence(self) -> bool:
        """
        Check for the presence of other ultrasonic sensors by detecting ultrasonic sounds. If the other ultrasonic sensor is operating in silent mode, you can only detect the presence of that sensor while it is taking a measurement.

        ----------
        Returns - True if ultrasonic sounds are detected, False if not.
        """
        ...


class GyroSensor:
    """
    LEGO® MINDSTORMS® EV3 Gyro Sensor. Element 99380/6138411, contained in:
    - 45544: LEGO® MINDSTORMS® Education EV3 Core Set (2013)
    - 45505: Separate part (2013)
    """

    def __init__(self, port: Port, direction: Direction = Direction.CLOCKWISE):
        """
        LEGO® MINDSTORMS® EV3 Gyro Sensor.

        ----------
        port : Port – Port to which the sensor is connected.

        direction : Direction – Positive rotation direction when looking at the red dot on top of the sensor (Default: Direction.CLOCKWISE).
        """
        ...

    def speed(self) -> int:
        """
        Get the speed (angular velocity) of the sensor.

        ----------
        Returns - Sensor angular velocity (degrees/second).
        """
        ...

    def angle(self) -> int:
        """
        Get the accumulated angle of the sensor.

        ----------
        Returns - Rotation angle (degrees).
        """
        ...

    def reset_angle(self, angle: int):
        """
        Set the rotation angle of the sensor to a desired value.

        ----------
        angle : float – Value to which the angle should be reset in degrees.
        """
        ...



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
        name="pybricks-stubs",
        version="0.0.2",
        author="Lawrence (Drew) Whisenant",
        author_email="dwhisenant@FIRSTinAlabama.org",
        description="An stubs package to write EV3 Python code.",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://github.com/drewwhis/pybricks-stubs",
        packages=setuptools.find_packages(),
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
)



from pybricks.ev3devices import Motor
from pybricks.parameters import Stop


class DriveBase:
    """
    Class representing a robotic vehicle with two powered wheels and optional wheel caster(s).
    """

    def __init__(self, left_motor: Motor, right_motor: Motor, wheel_diameter: int, axle_track: int):
        """
        Class representing a robotic vehicle with two powered wheels and optional wheel caster(s).

        ----------
        left_motor : Motor – The motor that drives the left wheel.

        right_motor : Motor – The motor that drives the right wheel.

        wheel_diameter : int – Diameter of the wheels (mm).

        axle_track : int – Distance between the midpoints of the two wheels (mm).
        """
        ...

    def drive(self, speed: float, steering: float):
        """
        Start driving at the specified speed and turnrate, both measured at the center point between the wheels ofthe robot.

        ----------
        speed : float – Forward speed of the robot (mm/s).

        steering : float - Turn rate of the robot (deg/s).
        """
        ...

    def drive_time(self, speed: float, steering: float, time: int):
        """
        Drive at the specified speed and turnrate for a given amount of time, and then stop.

        ----------
        speed : float – Forward speed of the robot (mm/s).

        steering : float – Turn rate of the robot (deg/s).

        time : int – Duration of the maneuver (ms).
        """
        ...

    def stop(self, stop_type: Stop = Stop.COAST):
        """
        Stop the robot.

        ----------
        stop_type : Stop – Whether to coast, brake, or hold (Default: Stop.COAST).
        """
        ...
